@@ -3,8 +3,8 @@
  * BROKER.C - Event broker routines for Icinga
  *
  * Copyright (c) 2002-2008 Ethan Galstad (egalstad@nagios.org)
- * Copyright (c) 2009-2011 Nagios Core Development Team and Community Contributors
- * Copyright (c) 2009-2011 Icinga Development Team (http://www.icinga.org)
+ * Copyright (c) 2009-2012 Nagios Core Development Team and Community Contributors
+ * Copyright (c) 2009-2012 Icinga Development Team (http://www.icinga.org)
  *
  * License:
  *
@@ -394,7 +394,7 @@ void broker_comment_data(int type, int flags, int attr, int comment_type, int en
 
 
 /* send downtime data to broker */
-void broker_downtime_data(int type, int flags, int attr, int downtime_type, char *host_name, char *svc_description, time_t entry_time, char *author_name, char *comment_data, time_t start_time, time_t end_time, int fixed, unsigned long triggered_by, unsigned long duration, unsigned long downtime_id, struct timeval *timestamp) {
+void broker_downtime_data(int type, int flags, int attr, int downtime_type, char *host_name, char *svc_description, time_t entry_time, char *author_name, char *comment_data, time_t start_time, time_t end_time, int fixed, unsigned long triggered_by, unsigned long duration, unsigned long downtime_id, struct timeval *timestamp, int is_in_effect, time_t trigger_time) {
 	nebstruct_downtime_data ds;
 
 	if (!(event_broker_options & BROKER_DOWNTIME_DATA))
@@ -420,6 +420,9 @@ void broker_downtime_data(int type, int flags, int attr, int downtime_type, char
 	ds.triggered_by = triggered_by;
 	ds.downtime_id = downtime_id;
 
+	ds.is_in_effect = is_in_effect;
+	ds.trigger_time = trigger_time;
+
 	/* make callbacks */
 	neb_make_callbacks(NEBCALLBACK_DOWNTIME_DATA, (void *)&ds);
 
