@@ -3,8 +3,8 @@
  * EVENTS.C - Timed event functions for Icinga
  *
  * Copyright (c) 1999-2010 Ethan Galstad (egalstad@nagios.org)
- * Copyright (c) 2009-2011 Nagios Core Development Team and Community Contributors
- * Copyright (c) 2009-2011 Icinga Development Team (http://www.icinga.org)
+ * Copyright (c) 2009-2012 Nagios Core Development Team and Community Contributors
+ * Copyright (c) 2009-2012 Icinga Development Team (http://www.icinga.org)
  *
  * License:
  *
@@ -367,7 +367,8 @@ void init_timing_loop(void) {
 
 			mult_factor = current_interleave_block + (interleave_block_index * total_interleave_blocks);
 
-			log_debug_info(DEBUGL_EVENTS, 2, "CIB: %d, IBI: %d, TIB: %d, SIF: %d\n", current_interleave_block, interleave_block_index, total_interleave_blocks, scheduling_info.service_interleave_factor);
+			log_debug_info(DEBUGL_EVENTS, 2, "CIB (current_interleave_block): %d, IBI (interleave_block_index): %d, TIB (total_interleave_blocks): %d, SIF (service_interleave_factor): %d\n",
+					current_interleave_block, interleave_block_index, total_interleave_blocks, scheduling_info.service_interleave_factor);
 			log_debug_info(DEBUGL_EVENTS, 2, "Mult factor: %d\n", mult_factor);
 
 			/* set the preferred next check time for the service */
@@ -1031,10 +1032,13 @@ void add_event(timed_event *event, timed_event **event_list, timed_event **event
 
 /* remove an event from the queue */
 void remove_event(timed_event *event, timed_event **event_list, timed_event **event_list_tail) {
-	timed_event *temp_event = NULL;
+	timed_event *prev_event, *next_event;
 
 	log_debug_info(DEBUGL_FUNCTIONS, 0, "remove_event()\n");
 
+	if (!event)
+		return;
+
 #ifdef USE_EVENT_BROKER
 	/* send event data to broker */
 	broker_timed_event(NEBTYPE_TIMEDEVENT_REMOVE, NEBFLAG_NONE, NEBATTR_NONE, event, NULL);
@@ -1043,31 +1047,38 @@ void remove_event(timed_event *event, timed_event **event_list, timed_event **ev
 	if (*event_list == NULL)
 		return;
 
-	if (*event_list == event) {
-		event->prev = NULL;
-		*event_list = event->next;
-		if (*event_list == NULL)
-			*event_list_tail = NULL;
+	/*
+	 * the event struct already holds next+prev ptrs
+	 * for the doubly linked list, so fetch them
+	 * and reassign previous with next, and reverse
+	 * check #2183 for a detailed description
+	 */
+	prev_event = event->prev;
+	next_event = event->next;
+
+	if (prev_event) {
+		prev_event->next = next_event;
+	}
+	if (next_event) {
+		next_event->prev = prev_event;
 	}
 
-	else {
-
-		for (temp_event = *event_list; temp_event != NULL; temp_event = temp_event->next) {
-			if (temp_event->next == event) {
-				temp_event->next = temp_event->next->next;
-				if (temp_event->next == NULL)
-					*event_list_tail = temp_event;
-				else
-					temp_event->next->prev = temp_event;
-				event->next = NULL;
-				event->prev = NULL;
-				break;
-			}
-		}
+	/* re-assign head and tail */
+	if (!prev_event) {
+		/* no previous event, so "next" is now first in list */
+		*event_list = next_event;
+	}
+	if (!next_event) {
+		/* no following event, so "prev" is now last in list */
+		*event_list_tail = prev_event;
 	}
 
-
-	return;
+	/*
+	 * If there was only one event in the list,
+	 * it's done just as if there were events before
+	 * and after the deleted event.
+	 * head and tail pointers are now NULL in this case
+	 */
 }
 
 
