@@ -3,7 +3,7 @@
  * STATUSWML.C -  Icinga Status CGI for WAP-enabled devices
  *
  * Copyright (c) 2001-2008 Ethan Galstad (egalstad@nagios.org)
- * Copyright (c) 2009-2011 Icinga Development Team (http://www.icinga.org)
+ * Copyright (c) 2009-2012 Icinga Development Team (http://www.icinga.org)
  *
  * License:
  *
@@ -69,16 +69,11 @@ int validate_arguments(void);
 int is_valid_hostip(char *hostip);
 
 int display_type = DISPLAY_INDEX;
-int show_all_hosts = TRUE;
 int show_all_hostgroups = TRUE;
-int show_all_servicegroups = TRUE;
 
 char *host_name = NULL;
-char *host_filter = NULL;
 char *hostgroup_name = NULL;
-char *servicegroup_name = NULL;
 char *service_desc = NULL;
-char *service_filter = NULL;
 int hostgroup_style = DISPLAY_HOSTGROUP_SUMMARY;
 int host_style = DISPLAY_HOST_SUMMARY;
 
@@ -114,7 +109,7 @@ int main(void) {
 	/* reset internal variables */
 	reset_cgi_vars();
 
-	document_header(CGI_ID, TRUE);
+	document_header(CGI_ID, TRUE, "Status WML");
 
 	/* validate arguments in URL */
 	result = validate_arguments();
