@@ -3,7 +3,7 @@
  * TRENDS.C -  Icinga State Trends CGI
  *
  * Copyright (c) 1999-2009 Ethan Galstad (egalstad@nagios.org)
- * Copyright (c) 2009-2011 Icinga Development Team (http://www.icinga.org)
+ * Copyright (c) 2009-2012 Icinga Development Team (http://www.icinga.org)
  *
  * License:
  *
@@ -32,19 +32,15 @@
 #include "../include/cgiutils.h"
 #include "../include/getcgi.h"
 #include "../include/cgiauth.h"
+#include "../include/skiplist.h"
 
 #include <gd.h>			/* Boutell's GD library function */
 #include <gdfonts.h>		/* GD library small font definition */
 
-
 /*#define DEBUG			1*/
 
-
 extern char main_config_file[MAX_FILENAME_LENGTH];
-extern char url_html_path[MAX_FILENAME_LENGTH];
 extern char url_images_path[MAX_FILENAME_LENGTH];
-extern char url_stylesheets_path[MAX_FILENAME_LENGTH];
-extern char url_js_path[MAX_FILENAME_LENGTH];
 extern char physical_images_path[MAX_FILENAME_LENGTH];
 
 extern int     log_rotation_method;
@@ -53,7 +49,6 @@ extern host *host_list;
 extern service *service_list;
 extern logentry *entry_list;
 
-#include "../include/skiplist.h"
 extern skiplist *object_skiplists[NUM_OBJECT_SKIPLISTS];
 
 /* archived state types */
@@ -120,7 +115,6 @@ int end_day = 1;
 int end_month = 1;
 int end_year = 2000;
 
-extern int content_type;
 int input_type = GET_INPUT_NONE;
 int timeperiod_type = TIMEPERIOD_LAST24HOURS;
 int compute_time_from_parts = FALSE;
@@ -131,6 +125,7 @@ int small_image = FALSE;
 extern int embedded;
 extern int display_header;
 extern int daemon_check;
+extern int content_type;
 
 int assume_initial_states = TRUE;
 int assume_state_retention = TRUE;
@@ -220,19 +215,10 @@ unsigned long time_warning = 0L;
 unsigned long time_unknown = 0L;
 unsigned long time_critical = 0L;
 
-int problem_found;
-
 int display_type = DISPLAY_NO_TRENDS;
-int show_all_hosts = TRUE;
-int show_all_hostgroups = TRUE;
-int show_all_servicegroups = TRUE;
 
 char *host_name = "";
-char *host_filter = NULL;
-char *hostgroup_name = NULL;
-char *servicegroup_name = NULL;
 char *service_desc = "";
-char *service_filter = NULL;
 
 int CGI_ID = TRENDS_CGI_ID;
 
@@ -249,9 +235,8 @@ int main(int argc, char **argv) {
 	host *temp_host = NULL;
 	service *temp_service = NULL;
 	int is_authorized = TRUE;
-	int found = FALSE;
+	int problem_found = FALSE;
 	int days, hours, minutes, seconds;
-	char *first_service = NULL;
 	time_t t3;
 	time_t current_time;
 	struct tm *t;
@@ -269,7 +254,7 @@ int main(int argc, char **argv) {
 	result = read_cgi_config_file(get_cgi_config_location());
 	if (result == ERROR) {
 		if (content_type == HTML_CONTENT) {
-			document_header(CGI_ID, FALSE);
+			document_header(CGI_ID, FALSE, "Error");
 			print_error(get_cgi_config_location(), ERROR_CGI_CFG_FILE);
 			document_footer(CGI_ID);
 		}
@@ -280,7 +265,7 @@ int main(int argc, char **argv) {
 	result = read_main_config_file(main_config_file);
 	if (result == ERROR) {
 		if (content_type == HTML_CONTENT) {
-			document_header(CGI_ID, FALSE);
+			document_header(CGI_ID, FALSE, "Error");
 			print_error(main_config_file, ERROR_CGI_MAIN_CFG);
 			document_footer(CGI_ID);
 		}
@@ -315,13 +300,10 @@ int main(int argc, char **argv) {
 	/* get the arguments passed in the URL */
 	process_cgivars();
 
-	/* get authentication information */
-	get_authentication_information(&current_authdata);
-
 	result = read_all_object_configuration_data(main_config_file, READ_ALL_OBJECT_DATA);
 	if (result == ERROR) {
 		if (content_type == HTML_CONTENT) {
-			document_header(CGI_ID, FALSE);
+			document_header(CGI_ID, FALSE, "Error");
 			print_error(NULL, ERROR_CGI_OBJECT_DATA);
 			document_footer(CGI_ID);
 		}
@@ -332,14 +314,17 @@ int main(int argc, char **argv) {
 	result = read_all_status_data(get_cgi_config_location(), READ_ALL_STATUS_DATA);
 	if (result == ERROR && daemon_check == TRUE) {
 		if (content_type == HTML_CONTENT) {
-			document_header(CGI_ID, FALSE);
+			document_header(CGI_ID, FALSE, "Error");
 			print_error(NULL, ERROR_CGI_STATUS_DATA);
 			document_footer(CGI_ID);
 		}
 		return ERROR;
 	}
 
-	document_header(CGI_ID, TRUE);
+	document_header(CGI_ID, TRUE, "Trends");
+
+	/* get authentication information */
+	get_authentication_information(&current_authdata);
 
 	if (compute_time_from_parts == TRUE)
 		compute_report_times();
@@ -377,7 +362,7 @@ int main(int argc, char **argv) {
 		else
 			snprintf(temp_buffer, sizeof(temp_buffer) - 1, "Host and Service State Trends");
 		temp_buffer[sizeof(temp_buffer)-1] = '\x0';
-		display_info_table(temp_buffer, FALSE, &current_authdata, daemon_check);
+		display_info_table(temp_buffer, &current_authdata, daemon_check);
 
 		if (timeperiod_type == TIMEPERIOD_NEXTPROBLEM) {
 			problem_t1 = 0;
@@ -386,7 +371,6 @@ int main(int argc, char **argv) {
 			t1 = t2;
 			t2 = current_time;
 			read_archived_state_data();
-			problem_found = FALSE;
 
 			if (display_type == DISPLAY_HOST_TRENDS) {
 				for (temp_as = as_list; temp_as != NULL; temp_as = temp_as->next) {
@@ -452,7 +436,7 @@ int main(int argc, char **argv) {
 #ifdef USE_HISTROGRAM
 				printf("<a href='%s?host=%s&t1=%lu&t2=%lu&assumestateretention=%s'>View Alert Histogram For This Host</a><BR>\n", HISTOGRAM_CGI, url_encode(host_name), t1, t2, (assume_state_retention == TRUE) ? "yes" : "no");
 #endif
-				printf("<a href='%s?host=%s&nostatusheader'>View Status Detail For This Host</a><BR>\n", STATUS_CGI, url_encode(host_name));
+				printf("<a href='%s?host=%s'>View Status Detail For This Host</a><BR>\n", STATUS_CGI, url_encode(host_name));
 				printf("<a href='%s?host=%s'>View Alert History For This Host</a><BR>\n", HISTORY_CGI, url_encode(host_name));
 				printf("<a href='%s?host=%s'>View Notifications For This Host</a><BR>\n", NOTIFICATIONS_CGI, url_encode(host_name));
 			} else {
@@ -914,46 +898,24 @@ int main(int argc, char **argv) {
 		/* ask the user for what service they want a report for */
 		else if (input_type == GET_INPUT_SERVICE_TARGET) {
 
-			printf("<SCRIPT LANGUAGE='JavaScript'>\n");
-			printf("function gethostname(hostindex){\n");
-			printf("hostnames=[");
-
-			for (temp_service = service_list; temp_service != NULL; temp_service = temp_service->next) {
-				if (is_authorized_for_service(temp_service, &current_authdata) == TRUE) {
-					if (found == TRUE)
-						printf(",");
-					else
-						first_service = temp_service->host_name;
-					printf(" \"%s\"", temp_service->host_name);
-					found = TRUE;
-				}
-			}
-
-			printf(" ]\n");
-			printf("return hostnames[hostindex];\n");
-			printf("}\n");
-			printf("</SCRIPT>\n");
-
-
 			printf("<P><DIV ALIGN=CENTER>\n");
 			printf("<DIV CLASS='reportSelectTitle'>Step 2: Select Service</DIV>\n");
 			printf("</DIV></P>\n");
 
 			printf("<P><DIV ALIGN=CENTER>\n");
 
-			printf("<form method=\"GET\" action=\"%s\" name=\"serviceform\">\n", TRENDS_CGI);
+			printf("<form method=\"POST\" action=\"%s\" name=\"serviceform\">\n", TRENDS_CGI);
 			printf("<input type='hidden' name='input' value='getoptions'>\n");
-			printf("<input type='hidden' name='host' value='%s'>\n", (first_service == NULL) ? "unknown" : (char *)escape_string(first_service));
 
 			printf("<TABLE BORDER=0 cellpadding=5>\n");
 			printf("<tr><td class='reportSelectSubTitle'>Service:</td>\n");
 			printf("<td class='reportSelectItem'>\n");
-			printf("<select name='service' onFocus='document.serviceform.host.value=gethostname(this.selectedIndex);' onChange='document.serviceform.host.value=gethostname(this.selectedIndex);'>\n");
+			printf("<select name='hostservice'>\n");
 
 			for (temp_service = service_list; temp_service != NULL; temp_service = temp_service->next) {
 				if (is_authorized_for_service(temp_service, &current_authdata) == TRUE)
 					temp_host = find_host(temp_service->host_name);
-				printf("<option value='%s'>%s;%s\n", escape_string(temp_service->description), (temp_host->display_name != NULL) ? temp_host->display_name : temp_host->name, (temp_service->display_name != NULL) ? temp_service->display_name : temp_service->description);
+				printf("<option value='%s^%s'>%s;%s\n", escape_string(temp_service->host_name), escape_string(temp_service->description), (temp_host->display_name != NULL) ? temp_host->display_name : temp_host->name, (temp_service->display_name != NULL) ? temp_service->display_name : temp_service->description);
 			}
 
 			printf("</select>\n");
@@ -1185,6 +1147,7 @@ int main(int argc, char **argv) {
 
 int process_cgivars(void) {
 	char **variables;
+	char *temp_buffer = NULL;
 	int error = FALSE;
 	int x;
 
@@ -1228,6 +1191,31 @@ int process_cgivars(void) {
 			display_type = DISPLAY_SERVICE_TRENDS;
 		}
 
+		/* we found a combined host/service */
+		else if (!strcmp(variables[x], "hostservice")) {
+			x++;
+			if (variables[x] == NULL) {
+				error = TRUE;
+				break;
+			}
+
+			temp_buffer = strtok(variables[x], "^");
+
+			if ((host_name = (char *)strdup(temp_buffer)) == NULL)
+				host_name = "";
+			else
+				strip_html_brackets(host_name);
+
+			temp_buffer = strtok(NULL, "");
+
+			if ((service_desc = (char *)strdup(temp_buffer)) == NULL)
+				service_desc = "";
+			else
+				strip_html_brackets(service_desc);
+
+			display_type = DISPLAY_SERVICE_TRENDS;
+		}
+
 		/* we found first time argument */
 		else if (!strcmp(variables[x], "t1")) {
 			x++;
