@@ -2,7 +2,7 @@
  *
  * PROTOAPI.H - IDO Protocol Definition
  * Copyright (c) 2005-2006 Ethan Galstad
- * Copyright (c) 2009-2011 Icinga Development Team (http://www.icinga.org)
+ * Copyright (c) 2009-2012 Icinga Development Team (http://www.icinga.org)
  *
  ************************************************************************/
 
@@ -107,7 +107,7 @@
 
 /************** COMMON DATA ATTRIBUTES **************/
 
-#define IDO_MAX_DATA_TYPES                           268
+#define IDO_MAX_DATA_TYPES                           270
 
 #define IDO_DATA_NONE                                0
 
@@ -388,4 +388,6 @@
 
 #define IDO_DATA_HOSTADDRESS6			     266
 #define IDO_DATA_END_TIME			     267    /* ACKNOWLEDGEMENT DATA */
+#define IDO_DATA_DOWNTIMEISINEFFECT		     268
+#define IDO_DATA_DOWNTIMETRIGGERTIME		     269
 #endif
