@@ -263,8 +263,6 @@ int             syslog_local_facility = DEFAULT_SYSLOG_LOCAL_FACILITY;
 
 int             log_current_states = DEFAULT_LOG_CURRENT_STATES;
 
-int             log_external_commands_user = DEFAULT_LOG_EXTERNAL_COMMANDS_USER;
-
 int             log_long_plugin_output = DEFAULT_LOG_LONG_PLUGIN_OUTPUT;
 
 int             service_check_timeout_state = STATE_CRITICAL;
@@ -272,6 +270,10 @@ int             service_check_timeout_state = STATE_CRITICAL;
 int             stalking_event_handlers_for_hosts = DEFAULT_STALKING_EVENT_HANDLERS_FOR_HOSTS;
 int             stalking_event_handlers_for_services = DEFAULT_STALKING_EVENT_HANDLERS_FOR_SERVICES;
 
+int dump_retained_host_service_states_to_neb = TRUE;
+int stalking_notifications_for_hosts = DEFAULT_STALKING_NOTIFICATIONS_FOR_HOSTS;
+int stalking_notifications_for_services = DEFAULT_STALKING_NOTIFICATIONS_FOR_SERVICES;
+
 /* Dummy variables */
 sched_info scheduling_info;
 timed_event event_list_low;
@@ -302,6 +304,8 @@ int neb_free_module_list(void) {}
 int     event_profiling_enabled = FALSE;
 void    profiler_update(int event, struct timeval start) {}
 
+void remove_host_acknowledgement(host * hst) {}
+void remove_service_acknowledgement(service * svc) {}
 
 int main(int argc, char **argv) {
 	int result;
@@ -324,7 +328,7 @@ int main(int argc, char **argv) {
 	int is_valid_time = 0;
 	int iterations = 1000;
 
-	plan_tests(6043);
+	plan(6043);
 
 	/* reset program variables */
 	reset_variables();
@@ -429,9 +433,9 @@ int main(int argc, char **argv) {
 
 	_get_next_valid_time(test_time, test_time, &chosen_valid_time, temp_timeperiod);
 	/* printf("JEAN: Got chosent time at %s", ctime(&chosen_valid_time)); */
-	todo_start("Bug in exclude");
+	todo("Bug in exclude");
 	ok(chosen_valid_time == 1288103400, "ME: Next valid time=Tue Oct 26 16:30:00 2010");
-	todo_end();
+	cendtodo();
 
 
 	temp_timeperiod = find_timeperiod("Test_exclude2");
@@ -442,9 +446,9 @@ int main(int argc, char **argv) {
 	ok(is_valid_time == ERROR, "ME: 12 Jul 2010 15:00:00 - false");
 	_get_next_valid_time(test_time, test_time, &chosen_valid_time, temp_timeperiod);
 	/* printf("JEAN: Got chosent time at %s", ctime(&chosen_valid_time)); */
-	todo_start("Bug in exclude 2");
+	todo("Bug in exclude 2");
 	ok(chosen_valid_time == 1279058340, "ME: Next valid time=Tue Jul 13 23:59:00 2010");
-	todo_end();
+	cendtodo();
 
 
 	temp_timeperiod = find_timeperiod("Test_exclude3");
@@ -455,9 +459,9 @@ int main(int argc, char **argv) {
 	ok(is_valid_time == ERROR, "ME: 12 Jul 2010 15:00:00 - false");
 	_get_next_valid_time(test_time, test_time, &chosen_valid_time, temp_timeperiod);
 	/* printf("JEAN: Got chosent time at %s", ctime(&chosen_valid_time)); */
-	todo_start("Bug in exclude 3");
+	todo("Bug in exclude 3");
 	ok(chosen_valid_time == 1284474600, "ME: Next valid time=Tue Sep 14 16:30:00 2010");
-	todo_end();
+	cendtodo();
 
 
 	temp_timeperiod = find_timeperiod("Test_exclude4");
@@ -468,9 +472,9 @@ int main(int argc, char **argv) {
 	ok(is_valid_time == ERROR, "ME: 12 Jul 2010 15:00:00 - false");
 	_get_next_valid_time(test_time, test_time, &chosen_valid_time, temp_timeperiod);
 	/* printf("JEAN: Got chosent time at %s", ctime(&chosen_valid_time)); */
-	todo_start("Bug in exclude 3");
+	todo("Bug in exclude 3");
 	ok(chosen_valid_time == 1283265000, "ME: Next valid time=Tue Aug 31 16:30:00 2010");
-	todo_end();
+	cendtodo();
 
 
 
@@ -515,9 +519,9 @@ int main(int argc, char **argv) {
 	is_valid_time = check_time_against_period(test_time, temp_timeperiod);
 	ok(is_valid_time == ERROR, "Sun Oct 25 01:26:40 2009 - false");
 	_get_next_valid_time(test_time, test_time, &chosen_valid_time, temp_timeperiod);
-	todo_start("Is a bug in get_next_valid_time for a time that falls in the DST change hour period");
+	todo("Is a bug in get_next_valid_time for a time that falls in the DST change hour period");
 	ok(chosen_valid_time == 1256440500, "Next valid time=Sun Oct 25 03:15:00 2009") || printf("chosen_valid_time=%lu\n", chosen_valid_time);
-	todo_end();
+	cendtodo();
 
 	test_time = 1256440500;
 	is_valid_time = check_time_against_period(test_time, temp_timeperiod);
